==> kubernetes-1.34.2.tar.gz: kubernetes-1.34.2/staging/src/k8s.io/code-generator/examples/apiserver/apis/example/v1/types.go <==
/*
Copyright 2015 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package v1

import metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"

// +genclient
// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

// TestType is a top-level type. A client is created for it.
type TestType struct {
	metav1.TypeMeta `json:",inline"`
	// +optional
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +optional
	Status TestTypeStatus `json:"status,omitempty"`
}

// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

// TestTypeList is a top-level list type. The client methods for lists are automatically created.
// You are not supposed to create a separated client for this one.
type TestTypeList struct {
	metav1.TypeMeta `json:",inline"`
	// +optional
	metav1.ListMeta `json:"metadata,omitempty"`

	Items []TestType `json:"items"`
}

type TestTypeStatus struct {
	Blah string `json:"blah"`
}

type Conversion struct {
	Identical MemoryIdentical `json:"identical"`
	Different MemoryDifferent `json:"different"`
}
type MemoryIdentical struct {
	Items *MemoryIdentical `json:"items,omitempty"`

	Properties map[string]MemoryIdentical `json:"properties,omitempty"`

	// +listType=atomic
	AllOf []MemoryIdentical `json:"allOf,omitempty"`

	Bool bool `json:"bool"`
}
type MemoryDifferent struct {
	Items *MemoryDifferent `json:"items,omitempty"`

	Properties map[string]MemoryDifferent `json:"properties,omitempty"`

	// +listType=atomic
	AllOf []MemoryDifferent `json:"allOf,omitempty"`

	Bool *bool `json:"bool"` // differs from internal representation
}

==> kubernetes-1.35.0.tar.gz: kubernetes-1.35.0/staging/src/k8s.io/code-generator/examples/apiserver/apis/example/v1/types.go <==
/*
Copyright 2015 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package v1

import metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"

// +genclient
// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

// TestType is a top-level type. A client is created for it.
type TestType struct {
	metav1.TypeMeta `json:",inline"`
	// +optional
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +optional
	Status TestTypeStatus `json:"status,omitempty"`
}

// +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

// TestTypeList is a top-level list type. The client methods for lists are automatically created.
// You are not supposed to create a separated client for this one.
type TestTypeList struct {
	metav1.TypeMeta `json:",inline"`
	// +optional
	metav1.ListMeta `json:"metadata,omitempty"`

	Items []TestType `json:"items"`
}

type TestTypeStatus struct {
	Blah string `json:"blah"`
}

type Conversion struct {
	Identical MemoryIdentical `json:"identical"`
	Different MemoryDifferent `json:"different"`
}
type MemoryIdentical struct {
	Items *MemoryIdentical `json:"items,omitempty"`

	Properties map[string]MemoryIdentical `json:"properties,omitempty"`

	// +listType=atomic
	AllOf []MemoryIdentical `json:"allOf,omitempty"`

	Bool bool `json:"bool"`
}
type MemoryDifferent struct {
	Items *MemoryDifferent `json:"items,omitempty"`

	Properties map[string]MemoryDifferent `json:"properties,omitempty"`

	// +listType=atomic
	AllOf []MemoryDifferent `json:"allOf,omitempty"`

	Bool *bool `json:"bool"` // differs from internal representation
}

type ConversionPrivate struct {
	PublicField  string `json:"publicField"`
	privateField string `json:"privateField"`
}

type ConversionCustomContainer struct {
	// +listType=atomic
	Slice []ConversionCustom `json:"slice"`
	// +listType=atomic
	SliceP  []*ConversionCustom          `json:"sliceP"`
	Map     map[string]ConversionCustom  `json:"map"`
	MapP    map[string]*ConversionCustom `json:"mapP"`
	Struct  ConversionCustom             `json:"struct"`
	StructP *ConversionCustom            `json:"structP"`
}
type ConversionCustom struct {
	PublicField  string `json:"publicField"`
	privateField string `json:"privateField"`
}
